Coverage report

# Coverage report: 99%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 1011 | 7 | 27 | 99%
/home/kale/kxgames/libraries/kxg/kxg/__init__.py | 9 | 0 | 0 | 100%
/home/kale/kxgames/libraries/kxg/kxg/actors.py | 76 | 3 | 6 | 96%
/home/kale/kxgames/libraries/kxg/kxg/errors.py | 36 | 0 | 7 | 100%
/home/kale/kxgames/libraries/kxg/kxg/forums.py | 145 | 0 | 0 | 100%
/home/kale/kxgames/libraries/kxg/kxg/messages.py | 98 | 0 | 1 | 100%
/home/kale/kxgames/libraries/kxg/kxg/multiplayer.py | 144 | 1 | 7 | 99%
/home/kale/kxgames/libraries/kxg/kxg/quickstart.py | 154 | 2 | 0 | 99%
/home/kale/kxgames/libraries/kxg/kxg/theater.py | 134 | 0 | 1 | 100%
/home/kale/kxgames/libraries/kxg/kxg/tokens.py | 215 | 1 | 5 | 99%

No items found using the specified filter.